@@ -1,12 +1,14 @@
 import logging
 from typing import List, Optional
 
+import pytest
 from _pytest._code.code import ExceptionChainRepr, ReprExceptionInfo
 from _pytest.nodes import Item
 from _pytest.reports import TestReport
 
 from pytest_zebrunner.api.client import ZebrunnerAPI
 from pytest_zebrunner.api.models import (
+    ArtifactReferenceModel,
     CorrelationDataModel,
     FinishTestModel,
     FinishTestSessionModel,
@@ -70,11 +72,20 @@ class ReportingService:
         milestone = (
             MilestoneModel(id=settings.milestone.id, name=settings.milestone.name) if settings.milestone else None
         )
+
+        if settings.run.context:
+            zebrunner_run_context = self.api.get_rerun_tests(settings.run.context)
+            if zebrunner_run_context.run_allowed:
+                pytest.exit(f"Run not allowed by zebrunner! Reason: {zebrunner_run_context.reason}")
+            if zebrunner_run_context.run_only_specific_tests and not zebrunner_run_context.tests_to_run:
+                pytest.exit("Aborted. No tests to run!!")
+
         test_run.zebrunner_id = self.api.start_test_run(
             settings.project_key,
             StartTestRunModel(
                 name=test_run.name,
                 framework="pytest",
+                uuid=zebrunner_run_context.test_run_uuid,
                 config=TestRunConfigModel(environment=test_run.environment, build=test_run.build),
                 milestone=milestone,
                 ci_context=resolve_ci_context(),
@@ -105,6 +116,13 @@ class ReportingService:
                 ),
             )
 
+            if report.artifact_references:
+                references = [ArtifactReferenceModel(name=x[0], value=x[1]) for x in report.artifact_references]
+                self.api.send_artifact_references(references, zebrunner_context.test_run_id, zebrunner_context.test_id)
+            if report.artifacts:
+                for artifact in report.artifacts:
+                    self.api.send_artifact(artifact, zebrunner_context.test_run_id, zebrunner_context.test_id)
+
     def finish_test(self, report: TestReport) -> None:
         if zebrunner_context.test_is_active:
             self.authorize()
@@ -183,7 +201,9 @@ class ReportingService:
         if run_context is not None:
             self.authorize()
             context_data = self.api.get_rerun_tests(run_context)
-            rerun_names = {x.correlation_data.name for x in context_data.tests if x.correlation_data is not None}
+            rerun_names = {
+                x.correlation_data.name for x in context_data.tests_to_run if x.correlation_data is not None
+            }
             return list(filter(lambda x: x.name in rerun_names, items)) if rerun_names else items
         else:
             return items
